import { Term, Topic, User } from '@holi/core/domain/shared/types'
import type { GeolocationPoint, Paged } from '@holi/core/types'

export enum VisibilityLevel {
  PUBLIC = 'PUBLIC',
  REGISTERED_USERS_ONLY = 'REGISTERED_USERS_ONLY',
}

export type Category = Term & { idx: number; label?: string }

export enum ReactionType {
  HEART = 'HEART',
}

export enum ReactionAction {
  'SET' = 'SET',
  'REMOVE' = 'REMOVE',
}

export interface ReactionCounts {
  HEART: number
}

interface Link {
  requestedUrl: string
  url: string
  title: string
  description: string
  type: string
  image: string
  siteName: string
  origin: string
  icon?: string
}

export interface FeedPostImage {
  id: string
  image: string
  imageBlurhash: string
  order: number
  altText?: string
}

export interface FeedPostImageMetadata {
  id: string
  order: number
  altText: string
}

export interface FeedPost {
  __typename: string
  id: string
  slug: string
  title: string
  description: string
  imageUrl?: string
  images?: FeedPostImage[]
  visibility: VisibilityLevel
  location?: string
  geolocation?: GeolocationPoint
  topics?: Topic[]
  category: Category
  author: User
  createdAt: string
  imageBlurhash?: string
  reactions: ReactionCounts
  myReaction: ReactionCounts
  linkPreview?: Link
  totalComments: number
  commenters: Paged<User>
  mentionedUsers?: User[]
  language?: string
}
